netapp_ontap.models.volume_error_state API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_error_state`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeErrorStateSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeErrorState object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `has_bad_blocks GET`

    Indicates whether the volume has any corrupt data blocks. If the damaged data block is accessed, an IO error, such as EIO for NFS or STATUS_FILE_CORRUPT for CIFS, is returned.

  `is_inconsistent GET`

    Indicates whether the file system has any inconsistencies.
    true ‐ File system is inconsistent.
    false ‐ File system in not inconsistent.